@@ -96,6 +96,8 @@ pub enum MarkerValueString {
     PlatformPythonImplementation,
     /// Deprecated `platform.python_implementation` from <https://peps.python.org/pep-0345/#environment-markers>
     PlatformPythonImplementationDeprecated,
+    /// Deprecated `python_implementation` from <https://github.com/pypa/packaging/issues/72>
+    PythonImplementationDeprecated,
     /// `platform_release`
     PlatformRelease,
     /// `platform_system`
@@ -119,9 +121,9 @@ impl Display for MarkerValueString {
             Self::PlatformMachine | Self::PlatformMachineDeprecated => {
                 f.write_str("platform_machine")
             }
-            Self::PlatformPythonImplementation | Self::PlatformPythonImplementationDeprecated => {
-                f.write_str("platform_python_implementation")
-            }
+            Self::PlatformPythonImplementation
+            | Self::PlatformPythonImplementationDeprecated
+            | Self::PythonImplementationDeprecated => f.write_str("platform_python_implementation"),
             Self::PlatformRelease => f.write_str("platform_release"),
             Self::PlatformSystem => f.write_str("platform_system"),
             Self::PlatformVersion | Self::PlatformVersionDeprecated => {
@@ -175,6 +177,9 @@ impl FromStr for MarkerValue {
             "platform.python_implementation" => {
                 Self::MarkerEnvString(MarkerValueString::PlatformPythonImplementationDeprecated)
             }
+            "python_implementation" => {
+                Self::MarkerEnvString(MarkerValueString::PythonImplementationDeprecated)
+            }
             "platform_release" => Self::MarkerEnvString(MarkerValueString::PlatformRelease),
             "platform_system" => Self::MarkerEnvString(MarkerValueString::PlatformSystem),
             "platform_version" => Self::MarkerEnvString(MarkerValueString::PlatformVersion),
@@ -230,15 +235,15 @@ impl MarkerOperator {
     /// Compare two versions, returning None for `in` and `not in`
     fn to_pep440_operator(&self) -> Option<pep440_rs::Operator> {
         match self {
-            MarkerOperator::Equal => Some(pep440_rs::Operator::Equal),
-            MarkerOperator::NotEqual => Some(pep440_rs::Operator::NotEqual),
-            MarkerOperator::GreaterThan => Some(pep440_rs::Operator::GreaterThan),
-            MarkerOperator::GreaterEqual => Some(pep440_rs::Operator::GreaterThanEqual),
-            MarkerOperator::LessThan => Some(pep440_rs::Operator::LessThan),
-            MarkerOperator::LessEqual => Some(pep440_rs::Operator::LessThanEqual),
-            MarkerOperator::TildeEqual => Some(pep440_rs::Operator::TildeEqual),
-            MarkerOperator::In => None,
-            MarkerOperator::NotIn => None,
+            Self::Equal => Some(pep440_rs::Operator::Equal),
+            Self::NotEqual => Some(pep440_rs::Operator::NotEqual),
+            Self::GreaterThan => Some(pep440_rs::Operator::GreaterThan),
+            Self::GreaterEqual => Some(pep440_rs::Operator::GreaterThanEqual),
+            Self::LessThan => Some(pep440_rs::Operator::LessThan),
+            Self::LessEqual => Some(pep440_rs::Operator::LessThanEqual),
+            Self::TildeEqual => Some(pep440_rs::Operator::TildeEqual),
+            Self::In => None,
+            Self::NotIn => None,
         }
     }
 }
@@ -389,7 +394,8 @@ impl MarkerEnvironment {
                 &self.platform_machine
             }
             MarkerValueString::PlatformPythonImplementation
-            | MarkerValueString::PlatformPythonImplementationDeprecated => {
+            | MarkerValueString::PlatformPythonImplementationDeprecated
+            | MarkerValueString::PythonImplementationDeprecated => {
                 &self.platform_python_implementation
             }
             MarkerValueString::PlatformRelease => &self.platform_release,
@@ -553,7 +559,7 @@ impl MarkerExpression {
         &self,
         env: &MarkerEnvironment,
         extras: &[ExtraName],
-        reporter: &mut impl FnMut(MarkerWarningKind, String, &MarkerExpression),
+        reporter: &mut impl FnMut(MarkerWarningKind, String, &Self),
     ) -> bool {
         match &self.l_value {
             // The only sound choice for this is `<version key> <version op> <quoted PEP 440 version>`
@@ -824,7 +830,7 @@ impl MarkerExpression {
         &self,
         l_string: &str,
         r_string: &str,
-        reporter: &mut impl FnMut(MarkerWarningKind, String, &MarkerExpression),
+        reporter: &mut impl FnMut(MarkerWarningKind, String, &Self),
     ) -> bool {
         match self.operator {
             MarkerOperator::Equal => l_string == r_string,
@@ -879,7 +885,7 @@ impl MarkerExpression {
         &self,
         value: &ExtraName,
         extras: &[ExtraName],
-        reporter: &mut impl FnMut(MarkerWarningKind, String, &MarkerExpression),
+        reporter: &mut impl FnMut(MarkerWarningKind, String, &Self),
     ) -> bool {
         match self.operator {
             MarkerOperator::Equal => extras.contains(value),
@@ -951,11 +957,11 @@ impl MarkerTree {
         };
         self.report_deprecated_options(&mut reporter);
         match self {
-            MarkerTree::Expression(expression) => expression.evaluate(env, extras, &mut reporter),
-            MarkerTree::And(expressions) => expressions
+            Self::Expression(expression) => expression.evaluate(env, extras, &mut reporter),
+            Self::And(expressions) => expressions
                 .iter()
                 .all(|x| x.evaluate_reporter_impl(env, extras, &mut reporter)),
-            MarkerTree::Or(expressions) => expressions
+            Self::Or(expressions) => expressions
                 .iter()
                 .any(|x| x.evaluate_reporter_impl(env, extras, &mut reporter)),
         }
@@ -980,11 +986,11 @@ impl MarkerTree {
         reporter: &mut impl FnMut(MarkerWarningKind, String, &MarkerExpression),
     ) -> bool {
         match self {
-            MarkerTree::Expression(expression) => expression.evaluate(env, extras, reporter),
-            MarkerTree::And(expressions) => expressions
+            Self::Expression(expression) => expression.evaluate(env, extras, reporter),
+            Self::And(expressions) => expressions
                 .iter()
                 .all(|x| x.evaluate_reporter_impl(env, extras, reporter)),
-            MarkerTree::Or(expressions) => expressions
+            Self::Or(expressions) => expressions
                 .iter()
                 .any(|x| x.evaluate_reporter_impl(env, extras, reporter)),
         }
@@ -1004,13 +1010,13 @@ impl MarkerTree {
         python_versions: &[Version],
     ) -> bool {
         match self {
-            MarkerTree::Expression(expression) => {
+            Self::Expression(expression) => {
                 expression.evaluate_extras_and_python_version(extras, python_versions)
             }
-            MarkerTree::And(expressions) => expressions
+            Self::And(expressions) => expressions
                 .iter()
                 .all(|x| x.evaluate_extras_and_python_version(extras, python_versions)),
-            MarkerTree::Or(expressions) => expressions
+            Self::Or(expressions) => expressions
                 .iter()
                 .any(|x| x.evaluate_extras_and_python_version(extras, python_versions)),
         }
@@ -1038,7 +1044,7 @@ impl MarkerTree {
         reporter: &mut impl FnMut(MarkerWarningKind, String, &MarkerExpression),
     ) {
         match self {
-            MarkerTree::Expression(expression) => {
+            Self::Expression(expression) => {
                 for value in [&expression.l_value, &expression.r_value] {
                     match value {
                         MarkerValue::MarkerEnvString(MarkerValueString::OsNameDeprecated) => {
@@ -1067,6 +1073,15 @@ impl MarkerTree {
                                 expression,
                             );
                         }
+                        MarkerValue::MarkerEnvString(
+                            MarkerValueString::PythonImplementationDeprecated,
+                        ) => {
+                            reporter(
+                                MarkerWarningKind::DeprecatedMarkerName,
+                                "python_implementation is deprecated in favor of platform_python_implementation".to_string(),
+                                expression,
+                            );
+                        }
                         MarkerValue::MarkerEnvString(
                             MarkerValueString::PlatformVersionDeprecated,
                         ) => {
@@ -1088,12 +1103,12 @@ impl MarkerTree {
                     }
                 }
             }
-            MarkerTree::And(expressions) => {
+            Self::And(expressions) => {
                 for expression in expressions {
                     expression.report_deprecated_options(reporter);
                 }
             }
-            MarkerTree::Or(expressions) => {
+            Self::Or(expressions) => {
                 for expression in expressions {
                     expression.report_deprecated_options(reporter);
                 }
@@ -1104,23 +1119,23 @@ impl MarkerTree {
 
 impl Display for MarkerTree {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        let format_inner = |expression: &MarkerTree| {
-            if matches!(expression, MarkerTree::Expression(_)) {
+        let format_inner = |expression: &Self| {
+            if matches!(expression, Self::Expression(_)) {
                 format!("{expression}")
             } else {
                 format!("({expression})")
             }
         };
         match self {
-            MarkerTree::Expression(expression) => write!(f, "{expression}"),
-            MarkerTree::And(and_list) => f.write_str(
+            Self::Expression(expression) => write!(f, "{expression}"),
+            Self::And(and_list) => f.write_str(
                 &and_list
                     .iter()
                     .map(format_inner)
                     .collect::<Vec<String>>()
                     .join(" and "),
             ),
-            MarkerTree::Or(or_list) => f.write_str(
+            Self::Or(or_list) => f.write_str(
                 &or_list
                     .iter()
                     .map(format_inner)
@@ -1377,7 +1392,7 @@ mod test {
     #[test]
     fn test_marker_equivalence() {
         let values = [
-            (r#"python_version == '2.7'"#, r#"python_version == "2.7""#),
+            (r"python_version == '2.7'", r#"python_version == "2.7""#),
             (r#"python_version == "2.7""#, r#"python_version == "2.7""#),
             (
                 r#"python_version == "2.7" and os_name == "posix""#,
