@@ -1,12 +1,14 @@
 use std::borrow::Cow;
 use std::fmt::Debug;
 use std::ops::Deref;
-use std::path::{Component, Path, PathBuf};
+use std::path::{Path, PathBuf};
 
 use once_cell::sync::Lazy;
 use regex::Regex;
 use url::{ParseError, Url};
 
+use uv_fs::normalize_path;
+
 /// A wrapper around [`Url`] that preserves the original string.
 #[derive(Debug, Clone, Eq, derivative::Derivative)]
 #[derivative(PartialEq, Hash)]
@@ -60,7 +62,7 @@ impl VerbatimUrl {
         };
 
         // Normalize the path.
-        let path = normalize_path(&path);
+        let path = normalize_path(path);
 
         // Convert to a URL.
         let url = Url::from_file_path(path).expect("path is absolute");
@@ -81,7 +83,7 @@ impl VerbatimUrl {
         };
 
         // Normalize the path.
-        let path = normalize_path(&path);
+        let path = normalize_path(path);
 
         // Convert to a URL.
         let url = Url::from_file_path(path).expect("path is absolute");
@@ -200,36 +202,6 @@ fn expand_env_vars(s: &str, escape: bool) -> Cow<'_, str> {
     })
 }
 
-/// Normalize a path, removing things like `.` and `..`.
-///
-/// Source: <https://github.com/rust-lang/cargo/blob/b48c41aedbd69ee3990d62a0e2006edbb506a480/crates/cargo-util/src/paths.rs#L76C1-L109C2>
-fn normalize_path(path: &Path) -> PathBuf {
-    let mut components = path.components().peekable();
-    let mut ret = if let Some(c @ Component::Prefix(..)) = components.peek().copied() {
-        components.next();
-        PathBuf::from(c.as_os_str())
-    } else {
-        PathBuf::new()
-    };
-
-    for component in components {
-        match component {
-            Component::Prefix(..) => unreachable!(),
-            Component::RootDir => {
-                ret.push(component.as_os_str());
-            }
-            Component::CurDir => {}
-            Component::ParentDir => {
-                ret.pop();
-            }
-            Component::Normal(c) => {
-                ret.push(c);
-            }
-        }
-    }
-    ret
-}
-
 /// Like [`Url::parse`], but only splits the scheme. Derived from the `url` crate.
 pub fn split_scheme(s: &str) -> Option<(&str, &str)> {
     /// <https://url.spec.whatwg.org/#c0-controls-and-space>
