@@ -18,6 +18,7 @@ use itertools::Itertools;
 use once_cell::sync::Lazy;
 use pyproject_toml::Project;
 use regex::Regex;
+use rustc_hash::FxHashMap;
 use serde::de::{value, SeqAccess, Visitor};
 use serde::{de, Deserialize, Deserializer, Serialize};
 use tempfile::{tempdir_in, TempDir};
@@ -28,7 +29,7 @@ use tracing::{debug, info_span, instrument, Instrument};
 
 use distribution_types::Resolution;
 use pep508_rs::Requirement;
-use uv_fs::Normalized;
+use uv_fs::Simplified;
 use uv_interpreter::{Interpreter, PythonEnvironment};
 use uv_traits::{BuildContext, BuildKind, ConfigSettings, SetupPyStrategy, SourceBuildTrait};
 
@@ -331,6 +332,10 @@ pub struct SourceBuild {
     package_id: String,
     /// Whether we do a regular PEP 517 build or an PEP 660 editable build
     build_kind: BuildKind,
+    /// Modified PATH that contains the `venv_bin`, `user_path` and `system_path` variables in that order
+    modified_path: OsString,
+    /// Environment variables to be passed in during metadata or wheel building
+    environment_variables: FxHashMap<OsString, OsString>,
 }
 
 impl SourceBuild {
@@ -349,6 +354,7 @@ impl SourceBuild {
         setup_py: SetupPyStrategy,
         config_settings: ConfigSettings,
         build_kind: BuildKind,
+        mut environment_variables: FxHashMap<OsString, OsString>,
     ) -> Result<Self, Error> {
         let temp_dir = tempdir_in(build_context.cache().root())?;
 
@@ -413,6 +419,36 @@ impl SourceBuild {
             .await
             .map_err(|err| Error::RequirementsInstall("build-system.requires (install)", err))?;
 
+        // Figure out what the modified path should be
+        // Remove the PATH variable from the environment variables if it's there
+        let user_path = environment_variables.remove(&OsString::from("PATH"));
+        // See if there is an OS PATH variable
+        let os_path = env::var_os("PATH");
+
+        // Prepend the user supplied PATH to the existing OS PATH
+        let modified_path = if let Some(user_path) = user_path {
+            match os_path {
+                // Prepend the user supplied PATH to the existing PATH
+                Some(env_path) => {
+                    let user_path = PathBuf::from(user_path);
+                    let new_path = env::split_paths(&user_path).chain(env::split_paths(&env_path));
+                    Some(env::join_paths(new_path).map_err(Error::BuildScriptPath)?)
+                }
+                // Use the user supplied PATH
+                None => Some(user_path),
+            }
+        } else {
+            os_path
+        };
+
+        // Prepend the venv bin directory to the modified path
+        let modified_path = if let Some(path) = modified_path {
+            let venv_path = iter::once(venv.scripts().to_path_buf()).chain(env::split_paths(&path));
+            env::join_paths(venv_path).map_err(Error::BuildScriptPath)?
+        } else {
+            OsString::from(venv.scripts())
+        };
+
         if let Some(pep517_backend) = &pep517_backend {
             create_pep517_build_environment(
                 &source_tree,
@@ -422,6 +458,8 @@ impl SourceBuild {
                 &package_id,
                 build_kind,
                 &config_settings,
+                &environment_variables,
+                &modified_path,
             )
             .await?;
         }
@@ -435,6 +473,8 @@ impl SourceBuild {
             config_settings,
             metadata_directory: None,
             package_id,
+            environment_variables,
+            modified_path,
         })
     }
 
@@ -575,9 +615,15 @@ impl SourceBuild {
             script="prepare_metadata_for_build_wheel",
             python_version = %self.venv.interpreter().python_version()
         );
-        let output = run_python_script(&self.venv, &script, &self.source_tree)
-            .instrument(span)
-            .await?;
+        let output = run_python_script(
+            &self.venv,
+            &script,
+            &self.source_tree,
+            &self.environment_variables,
+            &self.modified_path,
+        )
+        .instrument(span)
+        .await?;
         if !output.status.success() {
             return Err(Error::from_command_output(
                 "Build backend failed to determine metadata through `prepare_metadata_for_build_wheel`".to_string(),
@@ -642,7 +688,7 @@ impl SourceBuild {
             );
             let output = Command::new(python_interpreter)
                 .args(["setup.py", "bdist_wheel"])
-                .current_dir(self.source_tree.normalized())
+                .current_dir(self.source_tree.simplified())
                 .output()
                 .instrument(span)
                 .await
@@ -707,9 +753,15 @@ impl SourceBuild {
             script=format!("build_{}", self.build_kind),
             python_version = %self.venv.interpreter().python_version()
         );
-        let output = run_python_script(&self.venv, &script, &self.source_tree)
-            .instrument(span)
-            .await?;
+        let output = run_python_script(
+            &self.venv,
+            &script,
+            &self.source_tree,
+            &self.environment_variables,
+            &self.modified_path,
+        )
+        .instrument(span)
+        .await?;
         if !output.status.success() {
             return Err(Error::from_command_output(
                 format!(
@@ -755,6 +807,7 @@ fn escape_path_for_python(path: &Path) -> String {
 }
 
 /// Not a method because we call it before the builder is completely initialized
+#[allow(clippy::too_many_arguments)]
 async fn create_pep517_build_environment(
     source_tree: &Path,
     venv: &PythonEnvironment,
@@ -763,6 +816,8 @@ async fn create_pep517_build_environment(
     package_id: &str,
     build_kind: BuildKind,
     config_settings: &ConfigSettings,
+    environment_variables: &FxHashMap<OsString, OsString>,
+    modified_path: &OsString,
 ) -> Result<(), Error> {
     debug!(
         "Calling `{}.get_requires_for_build_{}()`",
@@ -786,9 +841,15 @@ async fn create_pep517_build_environment(
         script=format!("get_requires_for_build_{}", build_kind),
         python_version = %venv.interpreter().python_version()
     );
-    let output = run_python_script(venv, &script, source_tree)
-        .instrument(span)
-        .await?;
+    let output = run_python_script(
+        venv,
+        &script,
+        source_tree,
+        environment_variables,
+        modified_path,
+    )
+    .instrument(span)
+    .await?;
     if !output.status.success() {
         return Err(Error::from_command_output(
             format!("Build backend failed to determine extra requires with `build_{build_kind}()`"),
@@ -849,20 +910,18 @@ async fn run_python_script(
     venv: &PythonEnvironment,
     script: &str,
     source_tree: &Path,
+    environment_variables: &FxHashMap<OsString, OsString>,
+    modified_path: &OsString,
 ) -> Result<Output, Error> {
-    // Prepend the venv bin dir to PATH
-    let new_path = if let Some(old_path) = env::var_os("PATH") {
-        let new_path = iter::once(venv.scripts().to_path_buf()).chain(env::split_paths(&old_path));
-        env::join_paths(new_path).map_err(Error::BuildScriptPath)?
-    } else {
-        OsString::from("")
-    };
     Command::new(venv.python_executable())
         .args(["-c", script])
-        .current_dir(source_tree.normalized())
+        .current_dir(source_tree.simplified())
+        // Pass in remaining environment variables
+        .envs(environment_variables)
+        // Set the modified PATH
+        .env("PATH", modified_path)
         // Activate the venv
         .env("VIRTUAL_ENV", venv.root())
-        .env("PATH", new_path)
         .output()
         .await
         .map_err(|err| Error::CommandFailed(venv.python_executable().to_path_buf(), err))
