@@ -1,25 +1,25 @@
 use std::borrow::Cow;
-use std::path::Path;
+use std::path::{Component, Path, PathBuf};
 
-pub trait Normalized {
-    /// Normalize a [`Path`].
+pub trait Simplified {
+    /// Simplify a [`Path`].
     ///
     /// On Windows, this will strip the `\\?\` prefix from paths. On other platforms, it's a no-op.
-    fn normalized(&self) -> &Path;
+    fn simplified(&self) -> &Path;
 
     /// Render a [`Path`] for user-facing display.
     ///
     /// On Windows, this will strip the `\\?\` prefix from paths. On other platforms, it's
     /// equivalent to [`std::path::Display`].
-    fn normalized_display(&self) -> std::path::Display;
+    fn simplified_display(&self) -> std::path::Display;
 }
 
-impl<T: AsRef<Path>> Normalized for T {
-    fn normalized(&self) -> &Path {
+impl<T: AsRef<Path>> Simplified for T {
+    fn simplified(&self) -> &Path {
         dunce::simplified(self.as_ref())
     }
 
-    fn normalized_display(&self) -> std::path::Display {
+    fn simplified_display(&self) -> std::path::Display {
         dunce::simplified(self.as_ref()).display()
     }
 }
@@ -46,6 +46,36 @@ pub fn normalize_url_path(path: &str) -> Cow<'_, str> {
     }
 }
 
+/// Normalize a path, removing things like `.` and `..`.
+///
+/// Source: <https://github.com/rust-lang/cargo/blob/b48c41aedbd69ee3990d62a0e2006edbb506a480/crates/cargo-util/src/paths.rs#L76C1-L109C2>
+pub fn normalize_path(path: impl AsRef<Path>) -> PathBuf {
+    let mut components = path.as_ref().components().peekable();
+    let mut ret = if let Some(c @ Component::Prefix(..)) = components.peek().copied() {
+        components.next();
+        PathBuf::from(c.as_os_str())
+    } else {
+        PathBuf::new()
+    };
+
+    for component in components {
+        match component {
+            Component::Prefix(..) => unreachable!(),
+            Component::RootDir => {
+                ret.push(component.as_os_str());
+            }
+            Component::CurDir => {}
+            Component::ParentDir => {
+                ret.pop();
+            }
+            Component::Normal(c) => {
+                ret.push(c);
+            }
+        }
+    }
+    ret
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
