@@ -11,16 +11,17 @@ use distribution_types::{InstalledDist, InstalledMetadata, InstalledVersion, Nam
 use pep440_rs::{Version, VersionSpecifiers};
 use pep508_rs::{Requirement, VerbatimUrl};
 use requirements_txt::EditableRequirement;
-use uv_cache::ArchiveTimestamp;
-use uv_interpreter::Virtualenv;
+use uv_interpreter::PythonEnvironment;
 use uv_normalize::PackageName;
 
+use crate::{is_dynamic, not_modified};
+
 /// An index over the packages installed in an environment.
 ///
 /// Packages are indexed by both name and (for editable installs) URL.
 #[derive(Debug)]
 pub struct SitePackages<'a> {
-    venv: &'a Virtualenv,
+    venv: &'a PythonEnvironment,
     /// The vector of all installed distributions. The `by_name` and `by_url` indices index into
     /// this vector. The vector may contain `None` values, which represent distributions that were
     /// removed from the virtual environment.
@@ -35,7 +36,7 @@ pub struct SitePackages<'a> {
 
 impl<'a> SitePackages<'a> {
     /// Build an index of installed packages from the given Python executable.
-    pub fn from_executable(venv: &'a Virtualenv) -> Result<SitePackages<'a>> {
+    pub fn from_executable(venv: &'a PythonEnvironment) -> Result<SitePackages<'a>> {
         let mut distributions: Vec<Option<InstalledDist>> = Vec::new();
         let mut by_name = FxHashMap::default();
         let mut by_url = FxHashMap::default();
@@ -275,16 +276,12 @@ impl<'a> SitePackages<'a> {
                 }
                 [distribution] => {
                     // Is the editable out-of-date?
-                    let Ok(Some(installed_at)) =
-                        ArchiveTimestamp::from_path(distribution.path().join("METADATA"))
-                    else {
+                    if !not_modified(requirement, distribution) {
                         return Ok(false);
-                    };
-                    let Ok(Some(modified_at)) = ArchiveTimestamp::from_path(&requirement.path)
-                    else {
-                        return Ok(false);
-                    };
-                    if modified_at > installed_at {
+                    }
+
+                    // Does the editable have dynamic metadata?
+                    if is_dynamic(requirement) {
                         return Ok(false);
                     }
 
