@@ -6,16 +6,16 @@ use thiserror::Error;
 
 pub use crate::cfg::PyVenvConfiguration;
 pub use crate::interpreter::Interpreter;
+pub use crate::python_environment::PythonEnvironment;
 pub use crate::python_query::{find_default_python, find_requested_python};
 pub use crate::python_version::PythonVersion;
-pub use crate::virtual_env::Virtualenv;
 
 mod cfg;
 mod interpreter;
-mod python_platform;
+mod python_environment;
 mod python_query;
 mod python_version;
-mod virtual_env;
+mod virtualenv_layout;
 
 #[derive(Debug, Error)]
 pub enum Error {
@@ -28,7 +28,9 @@ pub enum Error {
     #[error("No versions of Python could be found. Is Python installed?")]
     PythonNotFound,
     #[error("Failed to locate a virtualenv or Conda environment (checked: `VIRTUAL_ENV`, `CONDA_PREFIX`, and `.venv`). Run `uv venv` to create a virtualenv.")]
-    NotFound,
+    VenvNotFound,
+    #[error("Failed to locate Python interpreter at: `{0}`")]
+    RequestedPythonNotFound(String),
     #[error(transparent)]
     Io(#[from] io::Error),
     #[error("Failed to query python interpreter `{interpreter}`")]
