@@ -14,7 +14,7 @@ use requirements_txt::EditableRequirement;
 use uv_cache::Cache;
 use uv_client::{Connectivity, FlatIndex, FlatIndexClient, RegistryClient, RegistryClientBuilder};
 use uv_dispatch::BuildDispatch;
-use uv_fs::Normalized;
+use uv_fs::Simplified;
 use uv_installer::{
     is_dynamic, not_modified, Downloader, NoBinary, Plan, Planner, Reinstall, ResolvedEditable,
     SitePackages,
@@ -84,7 +84,7 @@ pub(crate) async fn pip_sync(
     debug!(
         "Using Python {} environment at {}",
         venv.interpreter().python_version(),
-        venv.python_executable().normalized_display().cyan()
+        venv.python_executable().simplified_display().cyan()
     );
 
     // If the environment is externally managed, abort.
@@ -92,13 +92,13 @@ pub(crate) async fn pip_sync(
         return if let Some(error) = externally_managed.into_error() {
             Err(anyhow::anyhow!(
                 "The interpreter at {} is externally managed, and indicates the following:\n\n{}\n\nConsider creating a virtual environment with `uv venv`.",
-                venv.root().normalized_display().cyan(),
+                venv.root().simplified_display().cyan(),
                 textwrap::indent(&error, "  ").green(),
             ))
         } else {
             Err(anyhow::anyhow!(
                 "The interpreter at {} is externally managed. Instead, create a virtual environment with `uv venv`.",
-                venv.root().normalized_display().cyan()
+                venv.root().simplified_display().cyan()
             ))
         };
     }
