@@ -5,7 +5,7 @@ use std::process::Command;
 use anyhow::Result;
 use assert_fs::prelude::*;
 
-use uv_fs::Normalized;
+use uv_fs::Simplified;
 
 use crate::common::{
     create_bin_with_executables, get_bin, uv_snapshot, TestContext, EXCLUDE_NEWER,
@@ -21,12 +21,12 @@ fn create_venv() -> Result<()> {
     let venv = temp_dir.child(".venv");
 
     // Create a virtual environment at `.venv`.
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
         (
@@ -50,7 +50,7 @@ fn create_venv() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
     Activate with: source /home/ferris/project/.venv/bin/activate
     "###
@@ -59,12 +59,12 @@ fn create_venv() -> Result<()> {
     venv.assert(predicates::path::is_dir());
 
     // Create a virtual environment at the same location, which should replace it.
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
         (
@@ -89,7 +89,7 @@ fn create_venv() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
     Activate with: source /home/ferris/project/.venv/bin/activate
     "###
@@ -107,12 +107,12 @@ fn create_venv_defaults_to_cwd() -> Result<()> {
     let bin = create_bin_with_executables(&temp_dir, &["3.12"]).expect("Failed to create bin dir");
     let venv = temp_dir.child(".venv");
 
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
         (filter_prompt, "Activate with: source .venv/bin/activate"),
@@ -133,7 +133,7 @@ fn create_venv_defaults_to_cwd() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: .venv
     Activate with: source .venv/bin/activate
     "###
@@ -151,12 +151,12 @@ fn seed() -> Result<()> {
     let bin = create_bin_with_executables(&temp_dir, &["3.12"]).expect("Failed to create bin dir");
     let venv = temp_dir.child(".venv");
 
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
         (
@@ -182,7 +182,7 @@ fn seed() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
      + pip==23.3.1
     Activate with: source /home/ferris/project/.venv/bin/activate
@@ -201,12 +201,12 @@ fn seed_older_python_version() -> Result<()> {
     let bin = create_bin_with_executables(&temp_dir, &["3.10"]).expect("Failed to create bin dir");
     let venv = temp_dir.child(".venv");
 
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
         (
@@ -232,7 +232,7 @@ fn seed_older_python_version() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
      + pip==23.3.1
      + setuptools==68.2.2
@@ -300,11 +300,11 @@ fn create_venv_unknown_python_patch() -> Result<()> {
     let bin = create_bin_with_executables(&temp_dir, &["3.12"]).expect("Failed to create bin dir");
     let venv = temp_dir.child(".venv");
 
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (
             r"No Python 3\.8\.0 found through `py --list-paths` or in `PATH`\. Is Python 3\.8\.0 installed\?",
@@ -346,10 +346,10 @@ fn create_venv_python_patch() -> Result<()> {
         create_bin_with_executables(&temp_dir, &["3.12.1"]).expect("Failed to create bin dir");
     let venv = temp_dir.child(".venv");
 
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
-        (r"interpreter at .+", "interpreter at [PATH]"),
+        (r"interpreter at: .+", "interpreter at: [PATH]"),
         (&filter_venv, "/home/ferris/project/.venv"),
         (
             filter_prompt,
@@ -373,7 +373,7 @@ fn create_venv_python_patch() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python 3.12.1 interpreter at [PATH]
+    Using Python 3.12.1 interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
     Activate with: source /home/ferris/project/.venv/bin/activate
     "###
@@ -394,11 +394,11 @@ fn file_exists() -> Result<()> {
     // Create a file at `.venv`. Creating a virtualenv at the same path should fail.
     venv.touch()?;
 
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
     ];
@@ -419,7 +419,7 @@ fn file_exists() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
     uv::venv::creation
 
@@ -441,12 +441,12 @@ fn empty_dir_exists() -> Result<()> {
     // Create an empty directory at `.venv`. Creating a virtualenv at the same path should succeed.
     venv.create_dir_all()?;
 
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
         (
@@ -471,7 +471,7 @@ fn empty_dir_exists() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
     Activate with: source /home/ferris/project/.venv/bin/activate
     "###
@@ -493,11 +493,11 @@ fn non_empty_dir_exists() -> Result<()> {
     venv.create_dir_all()?;
     venv.child("file").touch()?;
 
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
     ];
@@ -518,7 +518,7 @@ fn non_empty_dir_exists() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
     uv::venv::creation
 
@@ -557,12 +557,12 @@ fn windows_shims() -> Result<()> {
     )?;
 
     // Create a virtual environment at `.venv`, passing the redundant `--clear` flag.
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
         (
-            r"Using Python 3\.8.\d+ interpreter at .+",
-            "Using Python 3.8.x interpreter at [PATH]",
+            r"Using Python 3\.8.\d+ interpreter at: .+",
+            "Using Python 3.8.x interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
         (
@@ -578,7 +578,7 @@ fn windows_shims() -> Result<()> {
         .arg(cache_dir.path())
         .arg("--exclude-newer")
         .arg(EXCLUDE_NEWER)
-        .env("UV_TEST_PYTHON_PATH", format!("{};{}", shim_path.display(), bin.normalized_display()))
+        .env("UV_TEST_PYTHON_PATH", format!("{};{}", shim_path.display(), bin.simplified_display()))
         .current_dir(&temp_dir), @r###"
     success: true
     exit_code: 0
@@ -586,7 +586,7 @@ fn windows_shims() -> Result<()> {
 
     ----- stderr -----
     warning: virtualenv's `--clear` has no effect (uv always clears the virtual environment).
-    Using Python 3.8.x interpreter at [PATH]
+    Using Python 3.8.x interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
     Activate with: source /home/ferris/project/.venv/bin/activate
     "###
@@ -605,12 +605,12 @@ fn virtualenv_compatibility() -> Result<()> {
     let venv = temp_dir.child(".venv");
 
     // Create a virtual environment at `.venv`, passing the redundant `--clear` flag.
-    let filter_venv = regex::escape(&venv.normalized_display().to_string());
+    let filter_venv = regex::escape(&venv.simplified_display().to_string());
     let filter_prompt = r"Activate with: (?:.*)\\Scripts\\activate";
     let filters = &[
         (
-            r"Using Python 3\.\d+\.\d+ interpreter at .+",
-            "Using Python [VERSION] interpreter at [PATH]",
+            r"Using Python 3\.\d+\.\d+ interpreter at: .+",
+            "Using Python [VERSION] interpreter at: [PATH]",
         ),
         (&filter_venv, "/home/ferris/project/.venv"),
         (
@@ -636,7 +636,7 @@ fn virtualenv_compatibility() -> Result<()> {
 
     ----- stderr -----
     warning: virtualenv's `--clear` has no effect (uv always clears the virtual environment).
-    Using Python [VERSION] interpreter at [PATH]
+    Using Python [VERSION] interpreter at: [PATH]
     Creating virtualenv at: /home/ferris/project/.venv
     Activate with: source /home/ferris/project/.venv/bin/activate
     "###
